__copyright__    = 'Copyright (C) 2020 Otsuka Kentaro'
__version__      = '0.0.1'
__license__      = 'MIT License'
__author__       = 'Otsuka Kentaro'
__author_email__ = 'otsuka.kenchan@gmail.com'
__url__          = 'https://github.com/otsuka-kentaro/tensorflow-modules'

__all__ = []
